@@ -68,6 +68,7 @@ json = JSONBackend()
 
 # Export specific JSONPluginMgr methods into the jsonpickle namespace
 set_preferred_backend = json.set_preferred_backend
+set_decoder_options = json.set_decoder_options
 set_encoder_options = json.set_encoder_options
 load_backend = json.load_backend
 remove_backend = json.remove_backend
@@ -81,9 +82,9 @@ def encode(value,
            max_depth=None,
            backend=None,
            warn=False,
-           max_iter=None):
-    """
-    Return a JSON formatted representation of value, a Python object.
+           max_iter=None,
+           numeric_keys=False):
+    """Return a JSON formatted representation of value, a Python object.
 
     :param unpicklable: If set to False then the output will not contain the
         information necessary to turn the JSON data back into Python objects,
@@ -129,12 +130,13 @@ def encode(value,
                           make_refs=make_refs,
                           keys=keys,
                           max_depth=max_depth,
-                          warn=warn)
+                          warn=warn,
+                          max_iter=max_iter,
+                          numeric_keys=numeric_keys)
 
 
 def decode(string, backend=None, keys=False):
-    """
-    Convert a JSON string into a Python object.
+    """Convert a JSON string into a Python object.
 
     The keyword argument 'keys' defaults to False.
     If set to True then jsonpickle will decode non-string dictionary keys
@@ -148,3 +150,8 @@ def decode(string, backend=None, keys=False):
     if backend is None:
         backend = json
     return unpickler.decode(string, backend=backend, keys=keys)
+
+
+# json.load(),loads(), dump(), dumps() compatibility
+dumps = encode
+loads = decode
